@@ -41,8 +41,6 @@
 
 #define KITEMVIEWS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KITEMVIEWS_NO_DEPRECATED) && !defined(KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KITEMVIEWS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMVIEWS_NO_DEPRECATED
-#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KITEMVIEWS_NO_DEPRECATED_WARNINGS
 #  define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KITEMVIEWS_DEPRECATED
-#  define KITEMVIEWS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KITEMVIEWS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KITEMVIEWS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
